## Summary

<!-- Brief description of the changes -->

## Changes

<!-- What was changed and why -->

-

## Checklist

- [ ] Tests added/updated
- [ ] `uv run ruff check src/ tests/` passes
- [ ] `uv run ruff format --check src/ tests/` passes
- [ ] `uv run mypy src/` passes
- [ ] `uv run pytest` passes
